package common.nbt;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;

class NBTTagDouble extends NBTBase
{
    private double data;

    NBTTagDouble()
    {
    }

    public NBTTagDouble(double data)
    {
        this.data = data;
    }

    void write(DataOutput output) throws IOException
    {
        output.writeDouble(this.data);
    }

    void read(DataInput input, int depth, SizeTracker sizeTracker) throws IOException
    {
        sizeTracker.read(16);
        this.data = input.readDouble();
    }

    public byte getId()
    {
        return (byte)6;
    }

    public String toString()
    {
        return "" + this.data + "d";
    }

    public NBTBase copy()
    {
        return new NBTTagDouble(this.data);
    }

    public boolean equals(Object other)
    {
        if (super.equals(other))
        {
            NBTTagDouble nbttagdouble = (NBTTagDouble)other;
            return this.data == nbttagdouble.data;
        }
        else
        {
            return false;
        }
    }

    public int hashCode()
    {
        long i = Double.doubleToLongBits(this.data);
        return super.hashCode() ^ (int)(i ^ i >>> 32);
    }

    public double getDouble()
    {
        return this.data;
    }
}
