package common.nbt;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;

class NBTTagString extends NBTBase {
	private String data;

	public NBTTagString() {
		this.data = "";
	}

	public NBTTagString(String data) {
		if(data == null)
			throw new IllegalArgumentException("null is not allowed");
		this.data = data;
	}

	void write(DataOutput output) throws IOException {
		output.writeUTF(this.data);
	}

	void read(DataInput input, int depth, SizeTracker tracker) throws IOException {
		tracker.read(36);
		this.data = input.readUTF();
		tracker.read(2 * this.data.length());
	}

	public byte getId() {
		return (byte)8;
	}

	public String toString() {
		return "\"" + this.data.replace("\"", "\\\"") + "\"";
	}

	public NBTBase copy() {
		return new NBTTagString(this.data);
	}

	public boolean equals(Object other) {
		if(!super.equals(other))
			return false;
		NBTTagString tag = (NBTTagString)other;
		return this.data == null && tag.data == null || this.data != null && this.data.equals(tag.data);
	}

	public int hashCode() {
		return super.hashCode() ^ this.data.hashCode();
	}

	public String getString() {
		return this.data;
	}
}
